==> ejc-sddjsorg-impl-3.0.0-20211019.091636-32-sources.jar: com/ejianc/business/production/bean/ReformNewShareholderEntity.java <==
package com.ejianc.business.production.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 产权登记-改制新股东
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sddjsorg_production_reform_new_shareholder")
public class ReformNewShareholderEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="captail_name")
    private java.lang.String captailName; // 出资方名称
    @TableField(value="unicode")
    private java.lang.String unicode; // 统一社会信用代码
    @TableField(value="be_actual_contributor")
    private java.lang.Integer beActualContributor; // 是否为国有实际出资人
    @TableField(value="supervise_org")
    private java.lang.String superviseOrg; // 归属监管机构
    
    
    

    /**
     * 出资方名称
     */
    public java.lang.String getCaptailName() {
        return captailName;
    }

    /**
     * 出资方名称
     */
    public void setCaptailName(java.lang.String captailName) {
        this.captailName = captailName;
    }
    /**
     * 统一社会信用代码
     */
    public java.lang.String getUnicode() {
        return unicode;
    }

    /**
     * 统一社会信用代码
     */
    public void setUnicode(java.lang.String unicode) {
        this.unicode = unicode;
    }
    /**
     * 是否为国有实际出资人
     */
    public java.lang.Integer getBeActualContributor() {
        return beActualContributor;
    }

    /**
     * 是否为国有实际出资人
     */
    public void setBeActualContributor(java.lang.Integer beActualContributor) {
        this.beActualContributor = beActualContributor;
    }
    /**
     * 归属监管机构
     */
    public java.lang.String getSuperviseOrg() {
        return superviseOrg;
    }

    /**
     * 归属监管机构
     */
    public void setSuperviseOrg(java.lang.String superviseOrg) {
        this.superviseOrg = superviseOrg;
    }
    
}

==> ejc-sddjsorg-impl-3.0.0-20211021.101505-46-sources.jar: com/ejianc/business/production/bean/ReformNewShareholderEntity.java <==
package com.ejianc.business.production.bean;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 产权登记-改制新股东
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sddjsorg_production_reform_new_shareholder")
public class ReformNewShareholderEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="captail_name")
    private java.lang.String captailName; // 出资方名称
    @TableField(value="unicode")
    private java.lang.String unicode; // 统一社会信用代码
    @TableField(value="be_actual_contributor")
    private java.lang.Boolean beActualContributor; // 是否为国有实际出资人
    @TableField(value="supervise_org")
    private java.lang.String superviseOrg; // 归属监管机构
    @TableField(value="pid")
    private Long pid;
    

    /**
     * 出资方名称
     */
    public java.lang.String getCaptailName() {
        return captailName;
    }

    /**
     * 出资方名称
     */
    public void setCaptailName(java.lang.String captailName) {
        this.captailName = captailName;
    }
    /**
     * 统一社会信用代码
     */
    public java.lang.String getUnicode() {
        return unicode;
    }

    /**
     * 统一社会信用代码
     */
    public void setUnicode(java.lang.String unicode) {
        this.unicode = unicode;
    }
    /**
     * 是否为国有实际出资人
     */
    public Boolean getBeActualContributor() {
        return beActualContributor;
    }

    public void setBeActualContributor(Boolean beActualContributor) {
        this.beActualContributor = beActualContributor;
    }

    /**
     * 归属监管机构
     */
    public java.lang.String getSuperviseOrg() {
        return superviseOrg;
    }

    /**
     * 归属监管机构
     */
    public void setSuperviseOrg(java.lang.String superviseOrg) {
        this.superviseOrg = superviseOrg;
    }

    public Long getPid() {
        return pid;
    }

    public void setPid(Long pid) {
        this.pid = pid;
    }
}
